
# q-expansion of newform 9036.2.a.l, downloaded from the LMFDB on 29 April 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 9036
weight = 2
poly_data = [4088, 4990, -9634, -10299, 5621, 5791, -1553, -1337, 267, 136, -26, -5, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[6, 1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-16616876824, -11591116006, 47057842184, 14051440227, -33080791624, -3669126359, 9351167288, -193383023, -1110023356, 116166372, 45468870, -7126353], 186594976], [[20662670920, 11280712834, -58056071608, -14431448017, 40917751336, 3681506813, -11641595816, 353069493, 1390057348, -152198396, -57189042, 9111803], 186594976], [[-32877029272, -20964832694, 90775884712, 27511515083, -62729626488, -8027070751, 17531461976, -109081671, -2071626668, 196928436, 84773334, -12779401], 186594976], [[-26137754024, -13934066566, 70876413112, 18115453619, -47881362992, -4928950511, 13093832192, -232061751, -1522474988, 152387372, 61624806, -9425689], 93297488], [[-17543307008, -10600922982, 47333637672, 14308235047, -32416561328, -4229274599, 9053974080, -40359615, -1071183884, 100728564, 43887146, -6589065], 46648744], [[10435206628, 5813572166, -28874223088, -7601090397, 19727433766, 2075212809, -5444625654, 96608525, 637057852, -64147390, -25889352, 3975487], 23324372], [[89270410920, 51452008610, -239842746680, -66747372273, 163483341144, 18574700365, -45376779608, 642642165, 5340298292, -530817628, -217959218, 33385083], 186594976], [[47538334360, 26699490506, -130374113464, -35387303293, 89471996672, 9893726625, -24897549136, 385468217, 2932646164, -293109828, -119721978, 18364375], 93297488], [[211095944072, 122381422770, -576899081688, -166057986393, 396993353112, 48080253797, -111091047592, 1121934957, 13149805716, -1280069804, -538736066, 81946099], 186594976]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0], [1, 0, 0, 0, 1, 0, -1, 0, -1, -1, 0, 0], [1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 1, -1, 0, 1, -1, -1, 0, -1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1], [1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0], [-2, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1], [0, 0, 0, 0, 0, -1, 0, 1, 0, 0, 0, -1], [2, 0, 0, 0, 1, 0, -1, 0, -1, -1, -1, 0], [-1, 0, 1, 0, -1, 0, 1, 1, 1, 0, 1, -1], [2, 0, 0, 0, 0, 0, 0, -1, -2, -1, 1, 0], [0, 1, 0, 0, 0, 0, 1, -1, 1, 0, -1, 0], [-1, 0, 0, -1, 0, 1, 1, -2, -1, -1, 1, 0], [0, 2, -1, 0, 2, -2, -1, 0, -1, 1, -1, 1], [1, 1, 0, -1, 1, 1, -1, -1, 0, 1, 0, 0], [0, 2, -2, 0, 0, 0, 0, 0, 1, 1, -1, 1], [2, 1, 0, 1, 0, 0, 1, -1, 0, 0, 0, -1], [4, 0, 0, 1, -1, -1, 2, -1, 2, 0, 1, 0], [-1, 1, 0, -1, 0, 1, -2, 1, 0, 1, 0, -1], [1, 0, 1, -1, 0, -1, 1, -2, 0, -1, 1, 0], [-1, -1, 0, 1, 0, 0, 1, 1, 0, 0, 1, -1], [4, 0, 0, 1, 0, -2, 0, -1, -2, 0, 1, 1], [-2, -1, -1, 0, 0, 1, 1, -2, 1, 0, 1, 1], [1, 2, -1, -1, -1, 0, -2, -1, 0, 0, 0, -2], [-2, 1, -2, 0, 0, -1, -1, -1, -1, 1, -2, 0], [4, 2, 0, 1, 1, 1, 0, 0, -1, -1, -2, 0], [1, -1, 0, 0, 0, -1, 0, 0, -2, -1, 3, -2], [2, -1, 1, -1, -1, -1, 0, 0, 0, -2, 0, -1], [-1, -2, 2, 0, -2, 1, 1, 2, 1, 1, 2, 1], [-1, -1, -1, 1, -1, 0, -1, 1, -1, -1, 0, 0], [2, 1, 1, 0, -2, 1, 1, 1, 1, 1, 0, 0], [-4, 0, -1, 0, -1, -1, -2, 1, 1, 1, -1, -1], [0, 0, -2, -2, -1, -1, -2, 0, 1, 2, 0, -1], [3, 2, -1, 0, 0, 0, -1, -1, 0, 1, 0, -1], [7, -1, 1, 1, 1, -1, 1, -1, 0, -1, 0, 0], [-1, 1, 1, -1, -1, 1, 2, -4, 2, 0, -1, 1], [-3, -1, 1, -1, 0, 1, -1, -2, 0, -2, -1, 0], [1, 1, -3, 0, -1, -1, -1, -1, 1, 0, 0, -1], [3, -1, 1, 0, -2, 1, 1, 2, 1, 1, -1, 1], [4, 1, -1, 2, 0, -3, 2, 1, 0, 0, 1, 1], [3, 0, -3, 0, -1, 1, 0, -1, 3, 1, -2, 1], [-6, 0, 1, 0, 0, 0, 2, 3, 2, 1, -3, 1], [6, 1, -2, 1, 3, -2, 0, 0, -2, -1, 1, -1], [1, 1, 1, 0, -2, 2, 0, -1, 2, 1, 1, 1], [2, -3, 2, 0, -2, 1, 2, -1, 3, 1, -2, 1], [2, 1, -2, 1, 2, 0, -1, 0, -1, 1, 1, -1], [5, 3, 0, 0, 3, -2, 1, -4, 0, -2, -2, 1], [-4, -1, -3, -1, 0, 0, 0, -3, 1, 1, 1, 0], [2, 4, -1, 0, 0, -2, 0, -3, 3, 2, 0, 0], [5, -1, 0, 3, 0, -2, 0, 4, 0, 0, 1, -2], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [3, -3, 0, -1, 0, -3, 2, -1, -2, -3, 2, 0], [4, 0, 1, 0, -1, 1, 1, 0, -3, 0, 0, 2], [-2, -1, -1, 1, 1, -3, -2, -1, -2, 1, 1, 1], [3, -1, 1, -1, 1, 1, -2, -2, -3, -1, 0, 2], [8, 1, -2, 1, 3, -2, -1, -1, -2, -2, -2, 2], [5, 0, -2, 1, 2, -1, 0, -5, 1, 0, -2, 1], [4, 3, 1, 1, -2, -1, -3, 3, -1, 2, 2, -3], [-1, 1, 1, -2, 0, 1, -1, -1, 0, 0, 2, -2], [3, -2, -1, 0, -1, 0, -3, 4, -1, 1, 4, 0], [1, 0, 1, -2, -1, 0, -2, 2, 2, 1, -4, 1], [9, 1, -1, 0, 0, -2, 2, 0, 1, 3, 1, -1], [-1, -3, 3, 4, -2, 0, 3, 2, 2, 0, 0, 0], [8, -2, 1, -1, 2, 0, -2, -3, -3, -5, 2, 0], [0, 0, -1, 0, 1, -1, -5, 2, -5, -1, -3, 0], [2, -1, 3, 1, 0, 2, 2, 1, 3, 3, 1, 0], [1, 0, -2, 0, 3, -3, 0, -1, -1, 1, -4, 3], [0, -2, -2, -1, 1, -2, -2, 2, 2, 1, -2, 2], [9, 2, 2, 2, 0, -3, 4, 0, 1, -2, -1, -3], [-3, 2, -1, -2, -1, 1, 1, -5, 3, 3, 0, 0], [7, 3, 1, 2, 0, -2, 3, 2, 0, 1, 1, -2], [2, 0, -1, 1, 1, 1, -3, -1, 1, 0, -1, -1], [5, 0, -1, -2, 1, -2, -3, -3, 0, -1, 2, -2], [2, 0, -3, 1, 2, 0, -3, 2, 0, 1, -2, 0], [0, 2, 2, 0, 1, 2, 2, 1, 3, 2, -2, -1], [1, -4, 2, -4, -2, 4, 0, -1, 1, 2, -1, 0], [-5, 5, -3, -1, 2, -1, -3, -2, 1, -1, -4, -1], [8, -1, -1, -1, -2, 3, -4, 1, -1, 0, 2, 0], [-1, -1, -1, 1, -1, -4, 1, -1, 4, 2, -1, 0], [12, 0, 0, 3, 5, -2, -1, -3, -4, -5, 0, -2], [6, -1, 0, -2, 0, 1, 1, -5, -3, -1, 2, 2], [1, 1, -2, 3, 1, -5, 0, 1, -2, -3, 2, -1], [6, 2, -1, -1, 3, 2, -3, 0, -5, 0, 1, 0], [6, -1, 2, 1, -1, 0, 0, 3, -1, 1, 1, -1], [3, -6, 0, -2, -2, 0, 0, -2, 0, -2, -1, 2], [7, 5, -5, 1, 4, -4, -6, -4, -2, 1, -2, 0], [-2, -1, 0, 2, 0, 2, 2, 4, -1, 1, -4, 5], [0, -3, -2, -3, 0, 1, 0, 0, 2, 2, 0, 0], [11, 0, 4, -1, 3, 0, -3, 2, -6, -3, 1, -1], [-5, -3, 2, -3, 2, 2, -1, 3, -3, -5, 0, 1], [8, 0, 0, -2, 1, 2, -1, -2, 1, -4, -6, 4], [-1, -3, 2, 4, -4, 0, 6, 3, 3, -2, 0, -1], [2, 3, -2, -2, 3, -3, -2, 2, -5, -3, -2, 2], [1, -4, 2, -1, 2, -1, 3, 0, 4, 0, 0, 0], [3, -9, 1, -1, -5, 2, 5, 3, 2, 0, 1, 2], [3, 2, -1, -2, 4, 0, -5, 0, 0, 2, 1, 0], [1, 1, 2, 1, -2, -2, 3, 5, 0, -1, 0, 1], [9, -6, 4, 4, 1, 1, 3, -2, 2, -3, 4, -1], [0, -1, 0, 0, -2, 1, 7, -5, 5, -1, 0, -2], [12, -8, -1, 2, 0, -3, 1, 2, -1, -4, 2, -3], [7, -3, 1, -2, -3, 1, -1, -3, -2, 0, 6, -2], [-5, 0, 1, 2, -4, 4, 4, -3, 4, 1, -2, 5], [-6, 0, 2, 2, 0, 2, 2, -1, -3, -1, 5, 0], [5, 1, 0, 1, 1, -3, 2, -2, -2, -1, -2, -1], [3, -2, -2, 3, 1, -2, 1, 0, -5, -2, -2, 0], [14, -2, 0, 0, -1, 5, 2, 0, 2, -1, -1, 3], [2, 2, -2, 2, 2, 1, 3, 1, 2, -2, -6, 1], [-8, 5, 1, -2, -1, 1, 3, -3, 6, 4, -3, 0], [3, -3, 0, -1, 0, 3, 0, 3, -3, -2, -1, -2], [12, -3, -3, 0, -1, -5, 2, 2, 1, 2, 3, -4], [-6, 4, 1, 3, -2, 1, 2, 5, 5, 4, -1, 2], [-6, 0, -4, -2, 0, -1, -2, -1, 4, 2, -2, 0], [9, -4, 2, 3, 1, -2, 1, 2, 2, 1, -1, -1], [-5, 4, -2, 1, -1, 2, 1, 0, -1, 4, 2, 1], [-4, 5, -2, -2, 1, -4, -6, 2, -1, 3, 0, -4], [-5, 0, 3, 3, 0, -1, 2, 0, 0, -4, -2, 3], [12, -1, -2, 1, -1, -1, 2, -2, 8, 0, -4, -1], [-8, 10, -3, -1, 1, -2, -1, 1, -1, 3, -4, 3], [9, -1, -1, -2, 1, 1, -3, -2, -4, -1, 5, -3], [-2, 2, -1, -5, -3, 3, 2, 0, 2, 2, 1, -1], [0, -1, 2, 1, 2, 4, -2, 4, 1, 0, 0, 1], [9, 1, -3, -1, 5, -1, -2, -3, -7, -6, 3, 1], [1, 3, 2, 2, 2, 3, 1, 2, -3, -4, -2, 2], [-3, -6, 0, -4, -5, 1, 0, 1, -1, 0, 1, -1], [3, 2, 0, 0, 1, 0, 1, 0, -4, 1, 2, 1], [-5, -2, 4, -3, -6, 7, 2, -1, 1, 4, 4, 0], [3, -3, -1, -1, 2, 1, 0, 3, 1, 0, 1, 0], [0, 3, -1, 5, 2, -4, 0, 1, -1, 3, 3, -2], [7, -5, 0, 0, 1, -1, 0, 5, -1, 2, 2, -1], [0, 4, 1, 0, 5, -3, -5, 3, -4, 2, -2, 2], [-13, -1, 3, 1, -3, 6, 1, 0, 6, 3, 0, -1], [2, -3, 3, -2, -3, 3, -3, 6, -3, 2, 3, -3], [-14, 1, 1, 0, 1, 1, 4, -2, 5, 0, -5, 4], [-12, 2, 3, -5, -1, 1, 6, -2, 0, 2, 3, 3], [-4, -2, -2, -7, -2, -1, -1, 2, -2, 2, 1, -2], [-4, -2, 2, 3, -1, 1, 8, 4, 1, 1, 0, 2], [2, -1, 0, -6, -1, -1, 3, -5, -2, -2, 5, -1], [11, 1, -5, 1, 5, -6, 1, -4, -1, 0, -3, 2], [-12, 7, -1, -1, 3, -2, -3, 3, 7, 3, -5, -1], [4, -1, -2, -3, 1, -6, 2, -3, -6, 0, 8, 1], [-5, -1, -1, -2, 0, 1, 3, 1, 0, -1, -3, -3], [-10, 5, -2, 2, 5, -7, -2, 1, -2, -2, -5, 2], [5, 5, -4, -7, -3, -1, -4, 2, 3, 7, -2, 0], [-3, 1, 0, -4, -1, -2, -5, 1, 4, 5, -5, 2], [-6, 4, -4, 2, -3, -3, 1, 1, 2, 2, -2, -2], [0, 1, 2, -4, 0, 2, -2, -1, 1, -2, 1, -2], [-6, 5, -1, 0, 0, -1, -5, 0, 0, 2, -1, 0], [-4, 7, -1, 7, 2, -5, -3, 1, -1, 3, -1, -2], [-4, 6, -3, 3, 1, -3, 3, -2, 1, -1, 0, 1], [11, -3, -3, 1, 0, 1, 4, -4, 5, -1, -8, 4], [-3, -1, 1, 2, -2, 3, 4, 0, 5, 6, -2, 1], [2, 5, -3, 1, 4, -3, 1, -2, 0, 0, -4, 0], [-1, 5, -3, -3, 1, 2, 0, -4, 4, 5, -2, -1], [-1, -4, -1, 1, -1, 3, 0, -4, -3, 3, 3, -2], [15, -9, 1, 2, -2, 1, -2, 0, -2, -3, -3, -3], [-6, 3, -4, 2, 0, -2, -7, 3, -1, 0, -1, -2], [12, -2, -1, 3, 3, -4, 3, -4, -5, -6, 3, -3], [-11, 4, -1, -2, 1, 1, 0, -4, 6, 8, -5, 1], [-3, -5, 3, -1, -4, 0, 5, 1, 1, -3, 2, 5], [3, -1, -3, 3, 1, -6, 5, -2, -2, -3, 2, -1], [-14, -3, 0, 2, -4, 1, 7, 7, 8, 7, 2, 1], [5, 1, 1, 1, -2, 2, 1, -3, -3, 1, 6, 3], [7, -5, -1, -2, 0, 1, 2, 4, -3, 0, 2, -3], [11, 3, 0, 0, 5, -2, -1, 1, -4, -9, -1, 1], [-5, -1, 0, 1, -2, -1, -2, -1, 3, 4, -3, 0], [-3, 6, -6, -2, 3, -5, -7, -6, -4, -3, -4, 1], [-20, 12, -4, 2, 4, -2, -3, 1, 0, 1, -7, 1], [9, -1, 0, -4, -1, 6, -4, -1, 2, -1, 1, 2], [0, 8, 0, -3, 3, 1, -6, 2, -5, 2, 7, -4], [3, -4, -3, -3, -2, 1, -3, -2, 1, 5, 3, -1], [4, 4, 1, 3, -2, 2, 4, -7, 0, -2, -3, 3], [-3, 2, -7, 3, 5, -3, -4, 0, -6, 0, 4, -1], [-13, 8, -3, 1, 6, -4, 2, -2, 2, 5, -7, 4], [6, -5, 0, -4, 1, 3, -7, 1, -2, -4, -1, 3], [-2, 4, -9, 1, 2, -7, -5, -6, -4, -2, -1, 0], [14, -4, 1, 0, 1, 0, -6, 5, -7, -4, 8, -3], [-5, -1, -1, -4, -2, 1, -4, -2, 1, -1, -3, 1], [1, 3, -4, 0, 7, -4, -7, -1, -4, 3, 1, -4], [-4, 4, -1, -1, -4, 2, 2, -1, 6, 8, 1, -1], [11, -3, 3, -3, 3, 2, -7, 1, -8, -5, 6, -4], [-13, 1, 0, 4, 2, -2, 2, -1, 3, 4, -4, 2], [-8, -2, -4, 3, 0, -1, -3, 1, -1, -2, -7, 2], [-3, 5, 0, -3, 5, 5, -10, -2, -5, -1, -4, 0], [-8, 4, -2, 3, 1, -3, -3, -2, 2, -1, -2, -3], [9, 5, 4, -3, -4, -1, -1, 6, 2, 4, -1, 0], [15, -2, 3, 3, 7, 2, 1, 2, -7, -7, 5, 4], [-8, -3, 2, -2, -4, 2, 3, 3, 5, 6, 3, -2], [11, -4, -1, -1, 1, 3, 1, 0, 3, -1, -3, -2], [0, 5, -6, 3, 3, -4, -6, 4, -6, 1, -3, 3], [3, -5, 7, -3, -1, 5, -3, -2, 0, -4, -1, -2], [-7, -5, 6, -4, -4, 3, 1, 0, 1, 0, 8, 0], [6, -2, -5, -1, -1, -6, 1, -6, -2, 1, 6, 3], [-11, -2, 4, -1, -3, -2, 4, -4, 4, 1, 3, -5], [-12, 5, -1, 3, 4, 2, -10, 5, -1, 0, -6, 4], [7, -4, 0, -2, -5, 3, -2, 6, 4, 2, 1, 1], [-2, 2, 0, -2, 5, 0, -8, 0, -8, -4, -2, 7], [4, -4, -3, -4, 1, 3, 1, -9, -2, -2, 2, -4], [0, 0, 0, 4, 4, 2, -3, -1, -4, -7, -1, -1], [-11, 7, -3, -4, -4, -1, -4, 1, 3, 7, -3, 2], [-1, 1, 0, -4, 1, -2, -5, -1, -6, -7, 1, -4], [0, 0, -7, 3, 6, -7, -11, -2, -7, 0, 3, -1], [12, -7, -2, -2, 1, 1, 5, 3, -1, -4, 1, 1], [-12, -3, -3, -3, -3, 0, -4, 0, 1, 0, 0, 0], [-2, 8, 1, 1, 5, -1, 4, -5, -1, -6, -9, 4], [-20, -4, -1, 2, -1, -2, 3, -2, 4, 1, -5, 3], [12, -1, 0, 1, 4, 4, -7, 1, -5, -7, -9, 7], [12, -4, 0, 5, -1, 1, -2, 4, 2, -2, 1, -3], [-1, -3, 4, 2, -5, 3, 9, -2, 2, -3, 3, 1], [-15, 6, 3, -3, 4, 5, -2, -2, -5, 1, -1, 1], [1, 12, 0, -2, -3, 2, -3, -1, -1, 2, 1, 1], [8, -3, -1, 2, 0, -3, 0, -2, -3, 1, 6, 3], [12, -11, -1, 4, -4, -2, 6, -1, 2, -2, 1, 1], [1, 3, 2, -7, 4, 2, -3, -2, -5, -1, 2, 3], [-9, -1, 3, -1, -1, 3, 6, -1, 6, 1, -6, -1], [12, 5, -4, -1, 8, -1, 1, -5, -1, 2, -4, 2], [-11, 3, 2, -3, 4, 0, 3, 4, -1, -2, -1, 1], [0, -3, -2, -2, 1, -4, -5, 5, -6, 5, 8, -6], [-1, 3, -7, 3, 3, -2, -4, -2, 4, 1, -4, -1], [-11, -1, 4, 4, -1, 3, 6, 3, 1, -1, -7, 5], [7, 10, -3, 4, 5, 0, -9, 0, -6, -2, 1, 3], [4, 0, -4, 4, 6, -1, -7, 6, -6, 3, -5, 5], [-28, 7, -3, -5, -6, -1, -1, 6, 3, 7, -3, 1], [-5, 1, -4, 6, 3, -3, -4, -1, -3, 3, 1, -3], [-8, 0, 4, 1, -10, 5, 0, 2, 2, 4, 1, -3], [20, -2, 0, -2, 3, -7, -5, 3, -6, -4, -4, -2], [-14, -4, 5, -3, 0, 6, -1, 6, 1, 0, 1, 1], [-1, -3, 3, -5, -2, -3, 6, -2, 1, -3, 0, 1], [-9, -3, -4, 0, 1, 4, -6, -3, 0, -2, 2, -4], [-3, 9, 1, 4, 0, 5, -2, -3, 0, 2, 2, 1], [-4, 1, 0, 1, -2, 1, -5, -1, 3, -2, 0, -5], [2, -9, -1, -1, -4, -1, 7, 4, 3, -1, 3, -3], [21, 0, 0, -1, -1, 3, -5, -2, -5, -3, -1, 5], [-1, 0, 1, 1, 6, -1, 7, 2, -2, -1, -7, 4], [4, 6, 1, 0, 3, -4, 1, -2, -9, -7, -3, 4], [-33, -2, -4, 2, 1, -1, 7, -2, 4, 5, -2, 4], [5, 3, -3, -3, -1, -6, 5, 1, 2, 6, 3, 2], [-9, -12, -5, 0, -5, 4, 0, -2, 5, 5, 0, 4], [2, -12, 12, -3, -3, 3, 3, 1, 0, -2, 3, -2], [17, -4, 5, -2, -6, -3, 8, -4, 7, 2, 5, -5], [4, 2, 0, -7, 5, -3, -8, -7, -5, -4, 1, -2], [-23, 3, -1, -2, 1, -2, 2, 1, 6, 11, -7, 0], [-16, -5, 6, 5, -3, 6, 4, 0, 5, 0, -2, 5], [10, 1, -7, -3, 10, -6, -2, 1, -5, 1, -3, -2], [-15, -8, 5, -3, -10, -2, 7, 6, 6, -3, 3, 0], [-17, 7, 2, 3, -3, -2, 4, -3, -3, -6, 3, 1], [-11, 9, 0, -3, -2, 3, -10, 2, 2, 4, -5, -2], [-7, -6, 10, -1, -3, 5, 0, 7, -4, -1, -1, -4], [-11, 2, -1, 3, 3, -5, -9, 4, -2, -1, -3, 3], [-1, -5, -4, -4, 8, -8, -9, 2, -9, -7, -1, -2], [-3, 0, -2, 4, 2, -2, -7, 0, -3, -2, -1, -1], [-9, 8, 1, 4, 0, -2, -5, 10, -4, 1, 2, 0], [-15, 1, 1, -5, -6, 4, 7, -3, 5, 5, 0, -1], [-15, -2, -2, 0, 3, 2, -5, 1, -1, 1, -4, -1], [-9, 5, 0, 2, -5, 2, -1, -2, 2, 3, 5, 1], [5, 12, -6, 1, 10, -4, 0, -8, -2, 1, -3, -2], [-33, 2, 4, -6, -10, 4, 3, 1, 5, 10, 3, -2], [9, -5, -3, 3, -2, -4, 8, 1, -1, 3, 0, 4], [3, -4, 3, -3, -2, -1, 1, -5, 8, 1, 7, -4], [8, -6, -2, -2, -8, 2, 1, -1, 3, -1, -1, -6], [4, -9, -5, -2, 2, 2, -2, -8, 1, -3, -2, 1], [-3, 11, -4, 1, 4, 4, -6, 3, -7, -1, 2, 0], [-9, -2, 4, -8, -6, 3, 4, -7, 4, -2, -7, 0], [-4, -5, 2, -1, -4, 6, 0, 4, -1, 4, 6, 4], [16, 3, -5, -1, 8, -3, 4, -7, -4, -3, -3, -2], [-2, -4, -6, -3, 1, -2, 3, -3, -2, -4, -1, 3], [18, -7, -1, -1, 4, 0, 0, -3, 0, -4, 2, 3], [-14, -1, -1, 1, 6, 1, -1, 5, -4, 1, -7, 1], [-6, -1, -5, -3, 6, 0, -7, -8, -3, -4, -4, 7], [-12, 6, 1, 5, 6, -3, 7, 1, -1, 0, -11, 4], [15, -2, -1, 1, -6, -2, 14, -9, 6, 2, 0, -3], [5, -4, 3, 3, -1, -1, 6, 2, 7, 5, -7, 2], [-3, 3, -2, 3, 2, -4, 9, -6, 4, -1, 4, -2], [20, -5, -3, 4, 3, -3, -8, 4, 0, 3, 0, 0], [-6, -5, -3, -4, 0, 0, -5, 6, -8, 0, 7, -4], [-14, 6, -3, 3, 5, -6, -5, -3, 5, 1, 0, -9], [-5, -5, 2, 2, -4, 5, 1, -3, 7, 7, -1, -2], [0, -6, 1, -1, -3, 8, 1, 4, -4, -1, 2, 1], [-24, 3, -7, -3, -4, -2, -2, -7, 2, 3, -5, 7], [14, -11, 1, 1, 6, -2, -3, 1, -6, -6, -2, 5], [12, 1, 0, -6, -2, 6, 6, -2, 5, 3, 4, -1], [6, -8, 3, 2, -3, 1, -5, 4, 1, -2, 4, 0], [16, -5, -3, -1, 0, -2, 10, -1, -6, 0, 2, 5], [-9, -3, -5, 2, -3, -1, -5, 4, 5, 2, 2, -6], [-16, 1, 10, -3, -2, 8, 4, 5, 1, 3, -5, 4], [0, 7, 2, 7, -2, 4, 5, -3, 5, 1, 1, 1], [-23, 5, 5, -5, -11, 3, 12, 0, 6, 6, -1, 3], [-5, 3, 2, -3, -7, 2, 3, 8, 3, 2, -3, 4], [11, 1, -3, 2, 0, -5, 3, 10, 0, 3, 1, 2], [-17, 2, -1, 2, -2, 0, 2, -4, 8, 4, -1, 0], [-6, 1, 5, 3, -5, -2, 8, 9, 2, 0, 0, -4], [-13, 6, -7, -4, 1, -6, -5, -4, -1, 4, 1, 2], [-17, 8, 4, -1, 1, -1, 10, 0, -1, -1, -3, 2], [-5, -4, -3, -2, -3, 1, 8, 4, 5, 2, -3, 6], [0, 9, -6, 0, 6, 2, -13, 3, -7, 2, -3, 0], [-3, -3, -2, 8, 0, -8, 7, 0, -1, 3, 5, 0], [10, -7, 2, -2, 1, 2, -4, 1, 1, 4, 3, 1], [13, 0, -3, 1, -1, 1, -2, -5, 3, -2, -2, 2], [-7, 11, 0, -5, -8, 0, -2, -3, 5, 5, 6, -4], [4, 2, -1, -6, 8, -2, -8, 2, -1, -3, -1, 1], [4, -10, -2, 0, -10, -3, 4, 3, 6, 4, -2, -2], [-17, -13, 1, -9, -7, 6, -1, -1, 6, 2, -1, 2], [16, 3, -7, 2, -1, -10, 2, 2, 2, 10, 1, 1], [-27, -4, -3, 2, 2, -5, 2, 1, 5, 8, -3, -2], [7, -1, 6, 0, 0, 7, 16, -5, 6, 0, 0, 3], [-13, -11, 6, -1, -6, 2, 10, 8, 2, -2, 3, -2], [-7, 2, 8, -1, -7, 9, -1, -5, 9, 3, 3, -7], [40, -11, -2, 3, -1, 2, -1, -1, 2, -7, -1, 2], [9, 0, -3, 1, 4, -4, 4, 4, 3, 0, 0, -3], [5, -5, 2, -6, 6, 1, -7, 6, -5, -8, -2, -6], [14, -7, 3, -4, 8, -3, 1, 2, -3, -4, -1, 1], [-9, 2, -2, 1, 6, -4, -1, -1, 1, 1, -3, 4], [18, -12, -1, 4, -4, -1, -3, 2, -4, 1, 7, -4], [4, -5, 5, 3, -6, 1, 12, -1, 5, -1, 3, 2], [12, 4, -3, 0, 0, -1, -6, 4, -2, 6, -2, -4], [18, -1, 7, 0, -3, 1, -2, 9, -7, -4, 3, -1], [29, 1, -3, 4, 8, -8, 2, -3, -7, -1, 1, 2], [20, -2, -2, -2, -7, 4, 14, -6, 9, 5, -1, 2], [14, -5, 2, 2, 6, -4, 3, -6, -3, -5, -4, 7], [6, 8, -5, -1, 10, -3, -5, -2, -8, 4, 5, 2], [-13, -5, 3, 2, -7, 3, -6, 6, -2, 3, 7, -4], [-15, 2, -3, -7, 5, 0, -9, 5, -3, -5, 5, -5], [-11, 4, 7, -3, -1, 3, -1, 7, 6, 3, -7, -3], [-15, -7, 6, 1, -12, 4, 16, 3, 13, 12, 1, -2], [16, -7, 1, 1, -4, -1, -1, 0, 3, 3, 3, -1], [4, -5, 0, -4, 0, 10, -6, 1, -5, 0, -3, 8], [-4, 0, 10, 3, 1, 3, -1, 9, -1, -4, 1, 5], [-12, 1, -1, 3, -5, 2, -2, -5, 6, 2, 0, 2], [-1, -1, 0, -3, 4, -8, -10, 3, -11, -9, 0, -4], [7, -5, 4, 5, -5, 6, 10, -7, 3, -3, 8, 3], [0, 0, -5, 0, 13, -10, -12, 6, -17, -11, -3, 1], [-7, 7, -5, -4, 5, -2, -3, -1, -7, -6, 4, 3], [11, 1, -3, 1, 1, 1, -3, 0, 0, 4, -7, 7], [-21, 5, 2, 1, -5, -3, -2, -3, 11, 4, -7, -3], [-13, -3, 0, -1, 3, 3, 1, -9, 0, -3, -2, 0], [14, 3, 0, -6, 8, -1, -5, -9, -12, -10, 5, -4], [1, 9, -6, 0, -5, -4, 0, -5, 2, 0, 6, -10], [-3, -3, 3, 4, 8, 6, -4, -1, -7, -12, -4, 2], [-15, 8, -3, -1, 4, -2, 5, 2, -4, 5, -7, 2], [-4, 4, 7, -2, -7, 9, 1, -4, 5, 4, 8, -4], [-9, -5, 7, -2, -6, 3, -3, 5, 4, -4, -4, 2], [-13, 8, 1, -1, -7, -1, 9, -10, 4, -2, 2, 1], [7, -7, -1, -4, 3, 10, -2, -10, -8, -6, -2, 5], [-9, -2, 9, -3, -9, 1, 6, 5, 7, 5, 5, 1], [-12, 1, 4, -3, 4, 4, -15, 6, -7, 0, 8, -1], [8, -12, -2, 1, -5, -5, 2, 3, 2, -3, 0, 2], [-10, -3, 1, 0, -5, -5, 5, 0, -3, -7, 10, -8], [-3, 1, -4, -3, 0, -3, 2, 3, -4, -3, -2, 6], [32, -19, 5, 8, 5, -3, -4, 5, -9, -9, 10, -9], [-2, 4, 4, 0, -2, 6, 10, -5, -4, -12, 4, 1], [2, -2, 5, -2, 0, 6, 2, 6, 1, 3, 3, -7], [-2, 7, -6, 3, 3, -1, -7, 2, -2, 2, 2, 7], [7, 3, 5, 2, -4, -4, 7, 1, 7, 2, 2, -4], [-4, 9, 4, -3, 8, -4, -5, -5, -7, -3, -3, 1], [16, 9, 0, 0, 3, -7, -7, -2, -2, -2, -3, -3], [-28, 2, 0, 8, 0, -1, -2, 4, -1, 1, 3, -1], [2, 0, -10, 8, 4, -8, -3, 3, -5, 0, 0, 1], [12, 13, -5, 6, 4, -7, 5, 5, 3, 8, -3, 4], [-24, 4, -3, -4, 7, -7, -5, -4, -3, 0, -2, 0], [14, 3, -3, -1, 5, -5, 12, -9, -2, -3, -1, 1], [5, -11, 2, -2, -3, -3, -4, 3, 2, -2, 0, 2], [18, 9, -7, 1, 7, -8, -9, -2, 3, 0, -8, -8], [-21, 5, -6, 0, -9, -2, -2, -1, 5, 10, -4, 3], [9, 0, 5, 10, -2, -1, 10, 8, 4, -4, 1, 0], [3, 8, -7, 4, 0, -6, 3, 5, 2, 9, -2, 1], [-13, -6, 4, 7, -2, 1, -5, 5, 0, -3, 3, -4], [-5, -11, 5, -4, -6, 9, -3, 5, -1, 1, 1, 0], [-30, 12, 0, 0, -3, -5, 5, 4, 9, 13, -5, 6], [-15, -3, 1, -1, -2, -8, -1, 3, 9, 1, -2, 1], [-12, 5, 1, 1, 5, 0, -5, 6, -3, 6, 4, -4], [22, 3, -1, 8, 7, -6, -6, 3, -16, -7, 6, 0], [2, -3, 1, 9, -2, -5, -5, 5, 3, 4, 4, -4], [-17, 5, 4, -5, -4, 7, 11, -6, 11, 3, -8, 5], [-16, 4, 1, -8, 1, 4, -6, 1, 2, 0, -4, 2], [6, 5, -5, 4, 0, 1, -11, 7, 2, 6, -1, -3], [-10, 0, -4, 2, 8, -6, -13, 10, -10, -5, -3, 0], [-16, -1, -6, 4, -2, -9, 10, 0, 4, 3, 2, 3], [0, -4, 10, 4, 5, 6, 12, 1, -3, -2, 0, 5], [-4, 5, 5, 1, -7, 8, 8, -3, 5, 1, -1, 9], [1, 2, -3, -8, 3, 1, 2, -2, 3, 6, -5, -4], [-2, -11, 6, 2, -10, 6, 4, 2, 3, -5, 4, 1], [23, 8, -5, 3, 10, -3, -6, 2, 2, 0, -6, 0], [6, -13, 8, 6, -4, 4, 6, 3, 8, -7, -2, -5], [-10, 3, -1, 3, 6, -8, -4, 3, -6, 3, 3, 3], [-1, 1, -3, 0, -2, 7, -11, -3, -4, -8, -6, -1], [5, -17, 0, 2, 3, 3, -3, -2, -6, -7, 3, 3], [7, -7, 5, 5, -1, 5, 10, -11, -4, -3, 2, -2], [-15, 14, 1, -10, 6, 5, -1, -7, 2, 0, -7, -3], [-15, 5, -4, -1, -4, -3, 0, 4, 2, 2, 1, 4], [-8, 4, -9, -5, -4, -1, -9, 4, 1, 5, 0, -2], [-20, 3, 6, 4, -7, 11, -1, 9, 13, 12, -7, -3], [-9, -2, -3, 7, 1, -7, 2, 10, 4, 2, 0, -3], [21, 13, -5, 0, 4, -1, -16, 0, -2, 2, -6, -2], [-13, -6, -3, -4, -11, 1, -6, 3, 3, 5, -4, 5], [6, -6, 7, -1, 4, 0, 9, -11, 0, -6, -1, 1], [22, 0, 7, -3, 1, -4, 6, 7, -3, -1, 2, 3], [-1, 4, 0, 7, -2, 0, -3, 5, 0, 6, -6, 5], [3, 15, -3, -4, 4, -10, -5, -7, 0, 1, -9, 2], [-17, -5, 8, 3, -11, 2, 6, 10, 12, 5, -4, -1], [8, 3, 8, 6, -5, -2, 10, -2, 0, -10, 3, -1], [-14, -16, 7, -3, -12, 12, 6, 2, 12, 9, 6, -3], [22, -8, -2, 2, 7, 2, -1, -7, -3, -8, -6, 5], [12, -2, 10, -1, -3, 9, 12, 3, 2, -1, 4, -4], [18, -9, 6, 7, 3, -2, 2, -7, 0, -8, 0, -7], [-13, -9, -2, -2, 1, -5, 5, -3, -14, -11, 9, -2], [19, -8, -2, 0, -2, 8, -4, 1, 6, 5, 6, 2], [17, 1, 4, -7, -9, 4, 4, -5, 6, 2, 9, -3], [2, 15, 1, 2, 6, 0, -9, 0, 2, -3, -10, 4], [8, -10, 5, 5, -1, 1, 3, 3, -1, 4, 3, -3], [5, 3, 8, -1, -7, 5, 0, 1, 4, 7, 4, 1], [10, -20, 2, 0, -5, 3, 9, -1, 6, -2, 0, 4], [-2, 6, -1, 4, -4, 8, -5, 2, 10, 6, -2, 5], [-25, 13, -10, 0, 11, -4, -1, 0, -2, 8, -4, 1], [-3, 8, -4, -5, -3, -9, -13, -4, -1, 1, 1, -4], [5, 2, 1, -5, 1, 7, 1, -4, 8, 8, -4, 3], [-13, 25, -7, -1, 9, -6, -11, -6, -4, -1, -10, -4], [1, -1, 7, 8, -11, 5, 13, -1, 5, -3, 3, -1], [29, 1, 1, 1, 12, 4, -11, -3, -12, -9, 2, -3], [10, 6, 6, -3, -5, 4, -4, -2, -2, 1, 6, 2], [-5, 1, 8, -4, -1, 3, -2, -5, 2, -7, -3, -6], [31, 10, -10, 7, 6, -3, -17, -6, -12, -4, 2, 0], [3, -7, 5, 2, -10, -2, 15, -1, 9, -2, -2, -6], [18, -4, -4, 4, 0, -7, -2, 2, 2, 2, 6, -8], [12, 4, -2, 4, 9, -2, -5, 1, -3, 0, -2, 5], [-12, -7, -2, 4, -6, -8, 8, 6, 3, 3, 10, -5], [25, -6, 2, -1, 1, -1, 3, 7, -2, 1, 3, 0], [14, 0, -5, -4, 8, -7, 6, -5, -4, 0, -2, 0], [-2, -11, 9, 6, -7, 6, 12, -1, 0, -3, 0, 0], [-15, 5, 1, -3, 1, 0, 3, -7, 4, -7, -10, 6], [-16, 2, -1, 1, -1, 2, 15, 2, 16, 7, -4, 1], [20, 7, 2, -2, 2, 2, -2, -3, 6, 1, -8, 3]]
